@@ -2,7 +2,9 @@
 Code Error
 """
 
-class CodeError(Exception):
+from .absexc import AbsurdException
+
+class CodeError(AbsurdException):
     """The code needs to RTFM."""
     pass
 
