@@ -2,7 +2,9 @@
 Developer Error
 """
 
-class DevError(Exception):
+from .absexc import AbsurdException
+
+class DevError(AbsurdException):
     """Developer needs to RTFM."""
     pass
 
