@@ -2,7 +2,9 @@
 WTF?
 """
 
-class DunnoError(Exception):
+from .absexc import AbsurdException
+
+class DunnoError(AbsurdException):
     """You have to ask 'wtf?' sometimes."""
     pass
 
