@@ -2,7 +2,9 @@
 Hardware Error
 """
 
-class HardwareError(Exception):
+from .absexc import AbsurdException
+
+class HardwareError(AbsurdException):
     """Problem in computer, not chair"""
     pass
 
