@@ -2,7 +2,9 @@
 Logic Error
 """
 
-class LogicError(Exception):
+from .absexc import AbsurdException
+
+class LogicError(AbsurdException):
     """Logic fucking died"""
     pass
 
