@@ -2,7 +2,9 @@
 User Error
 """
 
-class UserError(Exception):
+from .absexc import AbsurdException
+
+class UserError(AbsurdException):
     """User needs to RTFM."""
     pass
 
